marktools.get_marks_attached_to_components_in_expr
==================================================

.. autofunction:: abjad.tools.marktools.get_marks_attached_to_components_in_expr.get_marks_attached_to_components_in_expr
   :noindex:
